==> fluxbox-0.9.15.1.tar.gz: fluxbox-0.9.15.1/nls/C/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 BottomCenter
2 Bottom Left
3 Bottom Right
4 Horizontal
5 Left
6 Left Bottom
7 Left Center
8 Left Top
9 Relative
10 Right
11 Right Bottom
12 Right Center
13 Right Top
14 Top Center
15 Top Left
16 Top Right
17 Vertical

$set 2 #BaseDisplay

1 Aborting... dumping core\n
2 Shutting Down\n
3 %s:      signal %d caught\n

$set 3 #Common

1 Alpha
2 Auto hide
3 Compiled
4 Compiled options
5 Compiler
6 Compiler version
7 init
8 keys
9 nls
10 menu
11 style
12 Defaults
13 disabled
14 Error
15 Fluxbox version
16 Maximize Over
17 SVN Revision
18 Visible

$set 4 #Configmenu

1 AntiAlias
2 Auto Raise
3 Click Raises
4 Click to Focus
5 Decorate Transient Windows
6 Desktop MouseWheel Switching
7 Focus Window on Workspace Change
8 Focus Model
9 Focus New Windows
10 Full Maximization
11 Image Dithering
12 Opaque Window Moving
14 Mouse Focus
15 Workspace Warping
16 Force Pseudo-Transparency
17 Menu Alpha
18 Transparency
19 Focused Window Alpha
20 Unfocused Window Alpha

$set 5 #Ewmh

1 Fatal: Out of memory, can't allocate for EWMH client list

$set 6 #FbTkError

1 Warning! Height > 3200 setting Height = 3200
2 Warning! Width > 3200 setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Cant create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create %s directory
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome

1 Fatal: Out of memory, can't allocate for GNOME client list

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Configuration
2 Fluxbox default menu
3 Exit
4 Icons
5 Layer...
6 On Head...
7 Placement
8 Reload Config
9 Restart

$set 11 #Remember

1 Decorations
2 Dimensions
3 Jump to workspace
4 Layer
5 Remember...
6 Position
7 Save on close
8 Shaded
9 Sticky
10 Unknown apps key
11 Workspace
12 Head

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n

$set 13 #Slit

1 Clients
2 Cycle Down
3 Cycle Up
4 Slit Direction
5 Slit Layer
6 Slit on Head
7 Slit Placement
8 Slit
9 Save SlitList

$set 14 #Toolbar

1 Edit current workspace name
2 Iconbar Mode
3 All Windows
4 Icons
5 None
6 Workspace
7 WorkspaceIcons
8 Toolbar Layer
9 Toolbar on Head
10 Toolbar Placement
11 Toolbar
12 Toolbar width percent
13 Clock: 24h
14 Clock: 12h
15 Edit Clock Format
16 Show Pictures
17 NoIcons
18 WorkspaceNoIcons

$set 15 #Window

1 Unnamed

$set 16 #Windowmenu

1 Close
2 Iconify
3 Layer
4 Lower
5 Maximize
6 Raise
7 Send To ...
8 Shade
9 Stick
10 Kill

$set 17 #Workspace

1 Workspace %d
2 Workspaces
3 New Workspace
4 Remove Last

$set 18 #fbsetroot

1 Error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 error: '-display' requires an argument
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Unknown error
8 error: '-log' needs an argument
9 Log File
10 Logging to
11 error: '-rc' requires an argument
12 error: '-screen' requires an argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
Website: http://www.fluxbox.org/\n\n\
-display <string>\t\tuse display connection.\n\
-screen <all|int,int,int>\trun on specified screens only.\n\
-rc <string>\t\t\tuse alternate resource file.\n\
-version\t\t\tdisplay version and exit.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tdisplay this help text and exit.\n\n
14 warning: couldn't set environment variable 'DISPLAY'

$set 20

1 Above Dock
2 Bottom
3 Desktop
4 Dock
5 Normal
6 Top

==> fluxbox_1.3.5.orig.tar.gz: fluxbox-1.3.5/nls/C/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 Bottom Center
2 Bottom Left
3 Bottom Right
4 Horizontal_OBSOLETE
5 Left_OBSOLETE
6 Left Bottom
7 Left Center
8 Left Top
9 Relative_OBSOLETE
10 Right_OBSOLETE
11 Right Bottom
12 Right Center
13 Right Top
14 Top Center
15 Top Left
16 Top Right
17 Vertical_OBSOLETE
18 Center_OBSOLETE
19 Top_OBSOLETE
20 Bottom_OBSOLETE

$set 2 #BaseDisplay

1 Aborting... dumping core\n
2 Shutting Down\n
3 %s:      signal %d caught\n

$set 3 #Common

1 Alpha
2 Auto hide
3 Compiled
4 Compiled options
5 Compiler
6 Compiler version
7     init
8     keys
9      nls
10     menu
11    style
12 Defaults
13 disabled
14 Error
15 Fluxbox version
16 Maximize Over
17 GIT Revision
18 Visible
19 There is no background option specified in this style.\nPlease consult the manual or read the FAQ.

$set 4 #Configmenu

1 AntiAlias_OBSOLETE
2 Auto Raise
3 Click Raises
4 Click to Focus
5 Decorate Transient Windows_OBSOLETE
6 Desktop MouseWheel Switching_OBSOLETE
7 Focus Window on Workspace Change_OBSOLETE
8 Focus Model
9 Focus New Windows
10 Full Maximization
11 Image Dithering_OBSOLETE
12 Opaque Window Moving
13 Mouse Focus (Strict)
14 Mouse Focus
15 Workspace Warping
16 Force Pseudo-Transparency
17 Menu Alpha
18 Transparency
19 Focused Window Alpha
20 Unfocused Window Alpha
21 Tab Options
22 Tabs in Titlebar
23 External Tab Width
24 Click Tab Focus
25 Mouse Tab Focus
26 Maximize Options
27 Ignore Resize Increment
28 Disable Moving
29 Disable Resizing

$set 5 #Ewmh_OBSOLETE

1 Fatal: Out of memory, can't allocate for EWMH client list_OBSOLETE

$set 6 #FbTkError

1 Warning! Height > 3200, setting Height = 3200
2 Warning! Width > 3200, setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Can't create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile_OBSOLETE
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create directory %s
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome_OBSOLETE

1 Fatal: Out of memory, can't allocate for GNOME client list_OBSOLETE

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!_OBSOLETE
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Configuration
2 Fluxbox default menu
3 Exit
4 Icons
5 Layer...
6 On Head...
7 Placement
8 Reload Config
9 Restart
10 Warning: unbalanced [encoding] tags

$set 11 #Remember

1 Decorations
2 Dimensions
3 Jump to workspace
4 Layer
5 Remember...
6 Position
7 Save on close
8 Shaded
9 Sticky
10 Unknown apps key_OBSOLETE
11 Workspace
12 Head
13 Transparency
14 Minimized
15 Maximize
16 Fullscreen

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clients
2 Cycle Down
3 Cycle Up
4 Slit Direction:
5 Slit Layer
6 Slit on Head
7 Slit Placement
8 Slit
9 Save SlitList

$set 14 #Toolbar

1 Rename current workspace
2 Iconbar Mode
3 All Windows
4 Icons
5 None
6 Workspace
7 WorkspaceIcons
8 Toolbar Layer
9 Toolbar on Head
10 Toolbar Placement
11 Toolbar
12 Toolbar width percent
13 Clock: 24h
14 Clock: 12h
15 Edit Clock Format
16 Show Pictures
17 NoIcons
18 WorkspaceNoIcons

$set 15 #Window

1 Unnamed

$set 16 #Windowmenu

1 Close
2 Iconify
3 Layer
4 Lower
5 Maximize
6 Raise
7 Send To ...
8 Shade
9 Stick
10 Kill_OBSOLETE
11 Use Defaults_OBSOLETE
12 Set Window Title

$set 17 #Workspace

1 Workspace %d
2 Workspaces
3 New Workspace
4 Remove Last

$set 18 #fbsetroot

1 Error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 error: '-display' requires an argument
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Unknown error
8 error: '-log' needs an argument
9 Log File
10 Logging to
11 error: '-rc' requires an argument
12 error: '-screen' requires an argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
Website: http://www.fluxbox.org/\n\n\
-display <string>\t\tuse display connection.\n\
-screen <all|int,int,int>\trun on specified screens only.\n\
-rc <string>\t\t\tuse alternate resource file.\n\
-version\t\t\tdisplay version and exit.\n\
-info\t\t\t\tdisplay some useful information.\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tdisplay this help text and exit.\n\n
14 warning: couldn't set environment variable 'DISPLAY'

$set 20 #layers

1 Above Dock
2 Bottom
3 Desktop
4 Dock
5 Normal
6 Top
